@@ -109,7 +109,11 @@ class CategoricalPreModelAnalysis:
             top_features = self.n_cols
         else:
             sample_features = min(2 * 25, int(self.n_cols / 2))
-        top_feature_names = random.sample(self.cols_sorted[0:top_features], sample_features)
+
+        A = max(top_features, sample_features)
+        B = min(top_features, sample_features)
+        top_feature_names = random.sample(self.cols_sorted[0:A], B)
+
         feature_index = {feature: index for index, feature in enumerate(self.cols_sorted[0:top_features])}
         top_feature_names.sort(key=lambda x: feature_index[x])
         if self.data_info.problem_type_val in ["Binary regression", "Binary classification"]:
